@@ -36,6 +36,7 @@
 
 #include "libxfpm/xfpm-common.h"
 #include "libxfpm/xfpm-string.h"
+#include "libxfpm/xfpm-icons.h"
 
 #include "interfaces/xfpm-settings_ui.h"
 
@@ -1348,7 +1349,7 @@ xfpm_settings_advanced (XfconfChannel *channel, gboolean system_laptop, gboolean
     
 	val = xfconf_channel_get_uint (channel, PROPERTIES_PREFIX CRITICAL_POWER_LEVEL, 10);
 
-	if ( val > 20 || val < 5)
+	if ( G_UNLIKELY (val > 20) )
 	{
 	    g_critical ("Value %d if out of range for property %s\n", val, CRITICAL_POWER_LEVEL);
 	    gtk_spin_button_set_value (GTK_SPIN_BUTTON(critical_level), 10);
@@ -1451,7 +1452,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     gtk_tree_view_append_column(GTK_TREE_VIEW(view),col);
     
     /*General settings */
-    pix = xfpm_load_icon("preferences-system", 48); 
+    pix = xfce_themed_icon_load ("preferences-system", 48); 
     
     gtk_list_store_append(list_store, &iter);
     
@@ -1467,7 +1468,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     i++;
     
     /* ON ac power */
-    pix = xfpm_load_icon("xfpm-ac-adapter", 48); 
+    pix = xfce_themed_icon_load (XFPM_AC_ADAPTER_ICON, 48); 
     gtk_list_store_append(list_store, &iter);
     if ( pix )
     {
@@ -1482,7 +1483,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     
     if ( system_laptop )
     {
-	pix = xfpm_load_icon("battery", 48); 
+	pix = xfce_themed_icon_load (XFPM_BATTERY_ICON, 48); 
 	gtk_list_store_append(list_store, &iter);
 	if ( pix )
 	{
@@ -1496,7 +1497,7 @@ xfpm_settings_tree_view (XfconfChannel *channel, gboolean system_laptop)
     }
     i++;
     
-    pix = xfpm_load_icon("applications-other", 48); 
+    pix = xfce_themed_icon_load ("applications-other", 48); 
     gtk_list_store_append(list_store, &iter);
     if ( pix )
     {
