@@ -168,6 +168,19 @@ xfpm_brightness_hal_get_device (XfpmBrightnessHal *brg, const gchar *udi)
     g_object_unref (device);
 }
 
+static void
+xfpm_brightness_hal_read_hal_level (XfpmBrightnessHal *brg)
+{
+    GError *error = NULL;
+    
+    brg->priv->hw_level = xfpm_brightness_hal_get_level (brg, &error);
+   
+    if ( error )
+    {
+	g_warning ("Error getting brightness level: %s\n", error->message);
+	g_error_free (error);
+    }
+}
 
 static gboolean
 xfpm_brightness_hal_setup (XfpmBrightnessHal *brg)
@@ -188,7 +201,8 @@ xfpm_brightness_hal_setup (XfpmBrightnessHal *brg)
     xfpm_brightness_hal_get_device (brg, udi[0]);
     xfpm_brightness_hal_set_proxy (brg, udi[0]);
 
-    brg->priv->hw_level = xfpm_brightness_hal_get_level (brg, NULL);
+    xfpm_brightness_hal_read_hal_level (brg);
+    
     TRACE ("Current hw level =%d\n", brg->priv->hw_level);
     
     hal_manager_free_string_array (udi);
@@ -198,7 +212,6 @@ xfpm_brightness_hal_setup (XfpmBrightnessHal *brg)
 static void
 xfpm_brightness_hal_up (XfpmBrightnessHal *brg)
 {
-    GError *error = NULL;
     gboolean show_popup;
     gboolean enable_brightness;
     
@@ -217,14 +230,7 @@ xfpm_brightness_hal_up (XfpmBrightnessHal *brg)
     }
     
 signal:
-    brg->priv->hw_level = xfpm_brightness_hal_get_level (brg, &error);
-   
-    if ( error )
-    {
-	g_warning ("Error getting brightness level: %s\n", error->message);
-	g_error_free (error);
-	return;
-    }
+    xfpm_brightness_hal_read_hal_level (brg);
     
     if ( show_popup )
 	g_signal_emit (G_OBJECT (brg), signals [BRIGHTNESS_UP], 0, brg->priv->hw_level);
@@ -233,9 +239,7 @@ signal:
 static void
 xfpm_brightness_hal_down (XfpmBrightnessHal *brg)
 {
-    GError *error = NULL;
-    gboolean show_popup;
-    gboolean enable_brightness;
+    gboolean show_popup, enable_brightness;
     
     g_object_get (G_OBJECT (brg->priv->conf),
 		  ENABLE_BRIGHTNESS_CONTROL, &enable_brightness,
@@ -252,14 +256,7 @@ xfpm_brightness_hal_down (XfpmBrightnessHal *brg)
     }
     
 signal:
-    brg->priv->hw_level = xfpm_brightness_hal_get_level (brg, &error);
-    
-    if ( error )
-    {
-	g_warning ("Error getting brightness level: %s\n", error->message);
-	g_error_free (error);
-	return;
-    }
+    xfpm_brightness_hal_read_hal_level (brg);
     
     if ( show_popup )
 	g_signal_emit (G_OBJECT (brg), signals [BRIGHTNESS_UP], 0, brg->priv->hw_level);
@@ -301,7 +298,7 @@ xfpm_brightness_hal_reset_cb (XfpmIdle *idle, XfpmBrightnessHal *brg)
 	return;
     }
      
-    if ( level != brg->priv->hw_level )
+    if ( level != brg->priv->hw_level && level != 0)
     {
 	TRACE("Resetting brightness level to %d", brg->priv->hw_level);
 	xfpm_brightness_hal_set_level(brg, brg->priv->hw_level);
@@ -319,6 +316,8 @@ xfpm_brightness_timeout_on_ac (XfpmBrightnessHal *brg)
     
     level = xfpm_brightness_hal_get_level (brg, &error);
     
+    brg->priv->hw_level = level;
+    
     if ( error )
     {
 	g_warning ("Error getting brightness level: %s\n", error->message);
@@ -344,6 +343,8 @@ xfpm_brightness_timeout_on_battery (XfpmBrightnessHal *brg)
     
     level = xfpm_brightness_hal_get_level (brg, &error);
     
+    brg->priv->hw_level = level;
+    
     if ( error )
     {
 	g_warning ("Error getting brightness level: %s\n", error->message);
@@ -385,37 +386,37 @@ xfpm_brightness_hal_inhibit_changed_cb (XfpmScreenSaver *saver, gboolean inhibit
 }
 
 static void
-xfpm_brightness_get_user_timeouts (XfpmBrightnessHal *brg, guint16 *on_ac, guint16 *on_battery)
+xfpm_brightness_get_user_timeouts (XfpmBrightnessHal *brg, guint *timeout_on_ac, guint *timeout_on_battery)
 {
     g_object_get (G_OBJECT (brg->priv->conf),
-		  BRIGHTNESS_ON_AC, on_ac,
-		  BRIGHTNESS_ON_BATTERY, on_battery,
+		  BRIGHTNESS_ON_AC, timeout_on_ac,
+		  BRIGHTNESS_ON_BATTERY, timeout_on_battery,
 		  NULL);
 }
 
 static void
 xfpm_brightness_hal_set_timeouts (XfpmBrightnessHal *brg )
 {
-    guint16 on_ac, on_battery;
+    guint timeout_on_ac, timeout_on_battery ;
     
-    xfpm_brightness_get_user_timeouts (brg, &on_ac, &on_battery);
+    xfpm_brightness_get_user_timeouts (brg, &timeout_on_ac, &timeout_on_battery);
     
-    if ( on_ac == ALARM_DISABLED )
+    if ( timeout_on_ac == ALARM_DISABLED )
     {
 	xfpm_idle_free_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_AC );
     }
     else
     {
-	xfpm_idle_set_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_AC, on_ac * 1000);
+	xfpm_idle_set_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_AC, timeout_on_ac * 1000);
     }
     
-    if ( on_battery == ALARM_DISABLED )
+    if ( timeout_on_battery == ALARM_DISABLED )
     {
 	xfpm_idle_free_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_BATTERY );
     }
     else
     {
-	xfpm_idle_set_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_BATTERY, on_battery * 1000);
+	xfpm_idle_set_alarm (brg->priv->idle, TIMEOUT_BRIGHTNESS_ON_BATTERY, timeout_on_battery * 1000);
     }
     
     xfpm_idle_alarm_reset_all (brg->priv->idle);
