@@ -28,15 +28,11 @@
 #include <string.h>
 
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-
-#include <X11/Xproto.h>
-#include <X11/extensions/dpms.h>
-#include <X11/extensions/dpmsstr.h>
 
 #include <libxfce4util/libxfce4util.h>
 
 #include "libxfpm/xfpm-string.h"
+#include "libxfpm/xfpm-common.h"
 
 #include "xfpm-dpms.h"
 #include "xfpm-adapter.h"
@@ -60,6 +56,9 @@ struct XfpmDpmsPrivate
     gboolean       dpms_capable;
     gboolean       inhibited;
     gboolean       on_battery;
+    
+    gulong	   switch_off_timeout_id;
+    gulong	   switch_on_timeout_id;
 };
 
 G_DEFINE_TYPE(XfpmDpms, xfpm_dpms, G_TYPE_OBJECT)
@@ -93,7 +92,10 @@ xfpm_dpms_disable (XfpmDpms *dpms)
 	g_warning ("Cannot get DPMSInfo");
 	
     if ( state )
+    {
+	xfpm_dpms_set_timeouts (dpms, 0, 0, 0);
 	DPMSDisable (GDK_DISPLAY());
+    }
 }
 
 /*
@@ -238,6 +240,8 @@ xfpm_dpms_init(XfpmDpms *dpms)
     dpms->priv = XFPM_DPMS_GET_PRIVATE(dpms);
     
     dpms->priv->dpms_capable = DPMSCapable (GDK_DISPLAY());
+    dpms->priv->switch_off_timeout_id = 0;
+    dpms->priv->switch_on_timeout_id = 0;
 
     if ( dpms->priv->dpms_capable )
     {
@@ -271,9 +275,7 @@ xfpm_dpms_finalize(GObject *object)
     dpms = XFPM_DPMS (object);
     
     g_object_unref (dpms->priv->conf);
-	
     g_object_unref (dpms->priv->adapter);
-	
     g_object_unref ( dpms->priv->saver);
 
     G_OBJECT_CLASS(xfpm_dpms_parent_class)->finalize(object);
@@ -287,14 +289,53 @@ xfpm_dpms_new (void)
     return dpms;
 }
 
-/*
- * Get if the display is DPMS capable. if not the dpms
- * object is freed by xfpm-engine
- */
 gboolean xfpm_dpms_capable (XfpmDpms *dpms)
 {
     g_return_val_if_fail (XFPM_IS_DPMS(dpms), FALSE);
     
     return dpms->priv->dpms_capable;
 }
+
+void xfpm_dpms_force_level (XfpmDpms *dpms, CARD16 level)
+{
+    CARD16 current_level;
+    BOOL current_state;
+    
+    TRACE ("start");
+    
+    if ( !dpms->priv->dpms_capable )
+	goto out;
+    
+    if ( G_UNLIKELY (!DPMSInfo (GDK_DISPLAY (), &current_level, &current_state)) )
+    {
+	g_warning ("Cannot get DPMSInfo");
+	goto out;
+    }
+
+    if ( !current_state )
+    {
+	TRACE ("DPMS is disabled");
+	goto out;
+    }
+
+    if ( current_level != level )
+    {
+	TRACE ("Forcing DPMS mode %d", level);
+	
+	if ( !DPMSForceLevel (GDK_DISPLAY (), level ) )
+	{
+	    g_warning ("Cannot set Force DPMS level %d", level);
+	    goto out;
+	}
+	XSync (GDK_DISPLAY (), FALSE);
+    }
+    else
+    {
+	TRACE ("No need to change DPMS mode, current_level=%d requested_level=%d", current_level, level);
+    }
+    
+    out:
+	;
+}
+
 #endif /* HAVE_DPMS */
