@@ -49,6 +49,7 @@
 #include "xfpm-backlight.h"
 #include "xfpm-screen-saver.h"
 #include "xfpm-shutdown.h"
+#include "xfpm-button-hal.h"
 #include "xfpm-idle.h"
 #include "xfpm-errors.h"
 #include "xfpm-config.h"
@@ -76,6 +77,7 @@ struct XfpmEnginePrivate
     XfpmInhibit 	*inhibit;
     XfpmShutdown        *shutdown;
     XfpmButton          *button;
+    XfpmButtonHal       *bt_hal;
     XfpmIdle            *idle;
     XfpmScreenSaver     *srv;
 #ifdef HAVE_DPMS
@@ -230,20 +232,36 @@ xfpm_engine_shutdown_request_battery_cb (XfpmSupply * supply,
 }
 
 static void
-xfpm_engine_lid_event (XfpmEngine *engine)
+xfpm_engine_lid_event (XfpmButtonHal *bt_hal, gboolean pressed, XfpmEngine *engine)
 {
     XfpmLidTriggerAction action;
     
     g_object_get (G_OBJECT (engine->priv->conf),
-		  engine->priv->on_battery ? LID_SWITCH_ON_BATTERY_CFG : LID_SWITCH_ON_AC_CFG, &action,
-		  NULL);
-		  
-    XFPM_DEBUG_ENUM ("LID close event", action, XFPM_TYPE_LID_TRIGGER_ACTION);
-    
-    if ( action == LID_TRIGGER_LOCK_SCREEN )
-	xfpm_lock_screen ();
-    else 
-	xfpm_engine_shutdown_request (engine, action, FALSE);
+		      engine->priv->on_battery ? LID_SWITCH_ON_BATTERY_CFG : LID_SWITCH_ON_AC_CFG, &action,
+		      NULL);
+
+    if ( pressed )
+    {
+	XFPM_DEBUG_ENUM ("LID close event", action, XFPM_TYPE_LID_TRIGGER_ACTION);
+	
+	if ( action == LID_TRIGGER_NOTHING )
+	{
+	    if ( !xfpm_is_multihead_connected () )
+		xfpm_dpms_force_level (engine->priv->dpms, DPMSModeOff);
+	}
+	else if ( action == LID_TRIGGER_LOCK_SCREEN )
+	{
+	    if ( !xfpm_is_multihead_connected () )
+		xfpm_lock_screen ();
+	}
+	else 
+	    xfpm_engine_shutdown_request (engine, action, FALSE);
+    }
+    else
+    {
+	XFPM_DEBUG_ENUM ("LID opened", action, XFPM_TYPE_LID_TRIGGER_ACTION);
+	xfpm_dpms_force_level (engine->priv->dpms, DPMSModeOn);
+    }
 }
 
 static void
@@ -263,12 +281,6 @@ xfpm_engine_button_pressed_cb (XfpmButton *button,
     if ( type == BUTTON_MON_BRIGHTNESS_DOWN || type == BUTTON_MON_BRIGHTNESS_UP )
 	return;
     
-    if ( type == BUTTON_LID_CLOSED )
-    {
-	xfpm_engine_lid_event (engine);
-	return;
-    }
-    
     if ( type == BUTTON_POWER_OFF )
     {
 	g_object_get (G_OBJECT (engine->priv->conf),
@@ -378,6 +390,9 @@ xfpm_engine_load_all (gpointer data)
     g_signal_connect (engine->priv->button, "button-pressed",
 		      G_CALLBACK (xfpm_engine_button_pressed_cb), engine);
 
+    engine->priv->bt_hal = xfpm_button_hal_get ();
+    g_signal_connect (engine->priv->bt_hal, "lid_event",
+		      G_CALLBACK (xfpm_engine_lid_event), engine);
   /*
    * Brightness HAL
    */
@@ -591,6 +606,7 @@ xfpm_engine_finalize (GObject * object)
     g_object_unref (engine->priv->button);
     
     g_object_unref (engine->priv->idle);
+    g_object_unref (engine->priv->bt_hal);
 
 #ifdef HAVE_DPMS
     if (engine->priv->dpms)
